/*
 * Copyright (c) 1998, 1999, 2000, 2004, 2006, 2010
 *	Tama Communications Corporation
 *
 * This file is part of GNU GLOBAL.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _STRMAKE_H_
#define _STRMAKE_H_

#include <ctype.h>

#define	TRIM_HEAD	1
#define TRIM_TAIL	2
#define TRIM_BOTH	3
#define TRIM_ALL	4

#ifndef isblank
#define isblank(c)	((c) == ' ' || (c) == '\t')
#endif

#define SKIP_BLANKS(p)	do {						\
	while (*p && isblank((unsigned char)*p))			\
		p++;							\
} while (0)

const char *strmake(const char *, const char *);
const char *strtrim(const char *, int, int *);
int strcmp_withterm(const char *, const char *, int);
const char *strcpy_withterm(char *, const char *, int, int);

#endif /* ! _STRMAKE_H_ */
